@@ -22,7 +22,7 @@ __all__ = [
     "re_hash_to_name",
 ]
 
-_CHUNKSIZE = 0x100000  # 1 MB
+_CHUNKSIZE = 0x100000  # 1 MiB
 _HASH_LINE_RE = re.compile(r"([0-9a-fA-F]+)(?:(?: \*|  | )(.+))?")
 
 
@@ -33,6 +33,10 @@ class IsADirectory(OSError):
 class ParseHashLineError(ValueError):
     """Raised by :func:`parse_hash_line`."""
 
+    def __init__(self, hash_line):
+        super.__init__(hash_line)
+        self.hash_line = hash_line
+
 
 class CheckHashLineError(ValueError):
     """Raised by :func:`check_hash_line`."""
@@ -177,6 +181,9 @@ class Hasher(object):
 class HashFileReader(object):
     """General hash file reader.
 
+    The :class:`HashFileReader` supports the context manager protocol for
+    calling :meth:`HashFileReader.close` automatically.
+
     Parameters
     ----------
     filepath : str or path-like
@@ -187,7 +194,15 @@ class HashFileReader(object):
         self.name = filepath
         self.file = open(filepath, "r", encoding="utf-8")
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        self.close()
+
     def close(self):
+        """Close the underlying file."""
+
         self.file.close()
 
     def read_hash_line(self):
@@ -201,17 +216,21 @@ class HashFileReader(object):
 
         while True:
             line = self.file.readline()
-            if line.startswith("#"):
-                continue
-            # A empty string means EOF and will not give rise to infinite loop
-            # since ``''.isspace() == False``.
-            if line.isspace():
+            if not line:
+                break
+            if line.startswith("#") or line.isspace():
                 continue
             break
         return line  # empty string for EOF
 
     def iter(self):
-        """Yield hash line."""
+        """Yield hash line.
+
+        Yields
+        ------
+        hash_line : str
+            A line of *hash* and *name* with GNU Coreutils style.
+        """
 
         with self:
             while True:
@@ -220,42 +239,84 @@ class HashFileReader(object):
                     break
                 yield hash_line
 
+    __iter__ = iter
+
     def iter2(self, *, root=None):
-        """Yield hash and name."""
+        """Yield hash and name.
+
+        Parameters
+        ----------
+        root : str, path-like or None, optional
+            The root directory.
+
+        Yields
+        ------
+        hash : str
+            The hexadecimal hash value string.
+        name : str
+            The path of a file or a directory with corresponding hash value.
+        """
 
         for hash_line in self:
             yield parse_hash_line(hash_line, root=root)
 
     def iter3(self, *, root=None):
-        """Yield hash line, hash and name."""
+        """Yield hash line, hash and name.
+
+        Parameters
+        ----------
+        root : str, path-like or None, optional
+            The root directory.
+
+        Yields
+        ------
+        hash_line : str
+            A line of *hash* and *name* with GNU Coreutils style.
+        hash : str
+            The hexadecimal hash value string.
+        name : str
+            The path of a file or a directory with corresponding hash value.
+        """
 
         for hash_line in self:
             yield hash_line, *parse_hash_line(hash_line, root=root)
 
     def iter_hash(self):
-        """Yield hash."""
+        """Yield hash.
+
+        Yields
+        ------
+        hash : str
+            The hexadecimal hash value string.
+        """
 
         for entry in self.iter2():
             yield entry[0]
 
     def iter_name(self, *, root=None):
-        """Yield name."""
+        """Yield name.
+
+        Parameters
+        ----------
+        root : str, path-like or None, optional
+            The root directory.
+
+        Yields
+        ------
+        name : str
+            The path of a file or a directory with corresponding hash value.
+        """
 
         for entry in self.iter2(root=root):
             yield entry[1]
 
-    def __enter__(self):
-        return self
-
-    def __exit__(self, exc_type, exc_value, traceback):
-        self.close()
-
-    __iter__ = iter
-
 
 class HashFileWriter(object):
     """General hash file writer.
 
+    The :class:`HashFileWriter` supports the context manager protocol for
+    calling :meth:`HashFileReader.close` automatically.
+
     Parameters
     ----------
     filepath : str or path-like
@@ -266,7 +327,15 @@ class HashFileWriter(object):
         self.name = filepath
         self.file = open(filepath, "w", encoding="utf-8")
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        self.close()
+
     def close(self):
+        """Close the underlying file."""
+
         self.file.close()
 
     def write_hash_line(self, hash_line):
@@ -286,17 +355,11 @@ class HashFileWriter(object):
         Parameters
         ----------
         comment : str
-            A comment without leading ``#`` and tailing newline.
+            A line of comment without leading ``#`` and tailing newline.
         """
 
         self.file.write(f"# {comment}\n")
 
-    def __enter__(self):
-        return self
-
-    def __exit__(self, exc_type, exc_value, traceback):
-        self.close()
-
 
 def format_hash_line(hex_hash_value, path, *, root=None):
     r"""Format hash line.
@@ -312,7 +375,7 @@ def format_hash_line(hex_hash_value, path, *, root=None):
         (2) Relative path;
         (3) Relative to a given root directory.
     root : str, path-like or None, optional
-        The root directory of `path`.
+        The root directory.
 
     Returns
     -------
@@ -339,7 +402,7 @@ def parse_hash_line(hash_line, *, root=None):
     hash_line : str
         A line of *hash* and *name* with GNU Coreutils style.
     root : str, path-like or None, optional
-        The root directory of `path`.
+        The root directory.
 
     Returns
     -------
@@ -375,10 +438,10 @@ def generate_hash_line(path, hash_function, *, root=None):
     ----------
     path : str or path-like
         The path of a file or a directory with corresponding hash value.
-    hash_function : callable(str or path-like) -> bytes-like
+    hash_function : callable(str or path-like) -> bytes
         A function for generating hash value.
     root : str, path-like or None, optional
-        The root directory of `path`.
+        The root directory.
 
     Returns
     -------
@@ -398,10 +461,10 @@ def check_hash_line(hash_line, hash_function, *, root=None):
     ----------
     hash_line : str
         A line of *hash* and *name* with GNU Coreutils style.
-    hash_function : callable(str or path-like) -> bytes-like
+    hash_function : callable(str or path-like) -> bytes
         A function for generating hash value.
     root : str, path-like or None, optional
-        The root directory of `path`.
+        The root directory.
 
     Returns
     -------
@@ -431,7 +494,7 @@ def re_name_to_hash(hash_line, *, root=None):
     hash_line : str
         A line of *hash* and *name* with GNU Coreutils style.
     root : str, path-like or None, optional
-        The root directory of `path`.
+        The root directory.
 
     Returns
     -------
@@ -454,7 +517,7 @@ def re_hash_to_name(hash_line, *, root=None):
     hash_line : str
         A line of *hash* and *name* with GNU Coreutils style.
     root : str, path-like or None, optional
-        The root directory of `path`.
+        The root directory.
 
     Returns
     -------
