@@ -4,9 +4,16 @@ import os
 
 from . import _check_int, _check_str
 
-__all__ = ["glob_scanner", "glob_filter", "glob_scanners", "glob_filters", "sorted_locale"]
+__all__ = [
+    "glob_scanner",
+    "glob_filter",
+    "glob_scanners",
+    "glob_filters",
+    "sorted_locale",
+]
 
 _ESCAPE_SQUARE = glob.escape("[")
+_ESCAPE_SQUARE_BYTES = glob.escape(b"[")
 
 
 def _glob0(pathname, *, recursive=False):
@@ -14,8 +21,11 @@ def _glob0(pathname, *, recursive=False):
 
 
 def _glob1(pathname, *, recursive=False):
-    # Escape all square brackets to prevent glob from resolving them.
-    pathname = os.fspath(pathname).replace("[", _ESCAPE_SQUARE)
+    pathname = os.fspath(pathname)
+    if isinstance(pathname, bytes):
+        pathname = pathname.replace(b"[", _ESCAPE_SQUARE_BYTES)
+    else:
+        pathname = pathname.replace("[", _ESCAPE_SQUARE)
     yield from glob.iglob(pathname, recursive=recursive)
 
 
@@ -37,38 +47,14 @@ def _get_glob(mode):
 
 def _path_filter(pathnames, *, type):
     _check_str(type, "type")
-    all_ok = False
-    dir_ok = False
-    file_ok = False
-    link_ok = False
-    for t in set(type.lower()):
-        if t == "a":
-            all_ok = True
-        elif t == "d":
-            dir_ok = True
-        elif t == "f":
-            file_ok = True
-        elif t == "l":
-            link_ok = True
-        else:
-            raise ValueError(f"type must be in {{'a', 'd', 'f', 'l'}}, got '{t}'")
-
-    if all_ok:
-        yield from pathnames
+    if type == "a":
+        yield from filter(os.path.exists, pathnames)
+    elif type == "d":
+        yield from filter(os.path.isdir, pathnames)
+    elif type == "f":
+        yield from filter(os.path.isfile, pathnames)
     else:
-        for path in pathnames:
-            # Detect symlink first to avoid following symbolic links.
-            if os.path.islink(path):
-                if link_ok:
-                    yield path
-            elif os.path.isdir(path):
-                if dir_ok:
-                    yield path
-            elif os.path.isfile(path):
-                if file_ok:
-                    yield path
-            else:
-                raise ValueError(f"unexpected file type for path '{path}'")
+        raise ValueError(f"type must be in {{'a', 'd', 'f'}}, got '{type}'")
 
 
 def glob_scanner(pathname, *, mode=1, recursive=False):
@@ -76,7 +62,7 @@ def glob_scanner(pathname, *, mode=1, recursive=False):
 
     Parameters
     ----------
-    pathname : str or path-like
+    pathname : str, bytes or path-like
         A pathname with glob patterns.
     mode : int, default=1
         The mode of glob. If ``0``, disable glob pathname pattern; if ``1``,
@@ -87,7 +73,7 @@ def glob_scanner(pathname, *, mode=1, recursive=False):
 
     Yields
     ------
-    matched_pathname : str
+    matched_pathname : str or bytes
         The glob matched pathname.
     """
 
@@ -100,21 +86,21 @@ def glob_filter(pathname, *, mode=1, type="a", recursive=False):
 
     Parameters
     ----------
-    pathname : str or path-like
+    pathname : str, bytes or path-like
         A pathname with glob patterns.
     mode : int, default=1
         The mode of glob. If ``0``, disable glob pathname pattern; if ``1``,
         resolve ``*`` and ``?``; if ``2``, resolve ``*``, ``?`` and ``[]``.
     type : str, default='a'
         The type of file. If ``a``, include all types; if ``d``, include
-        directories; if ``f``, include files; if ``l``, includes symbolic links.
+        directories; if ``f``, include files.
     recursive : bool, default=False
         If ``True``, the pattern ``**`` will match any files and zero or more
         directories, subdirectories and symbolic links to directories.
 
     Yields
     ------
-    matched_pathname : str
+    matched_pathname : str or bytes
         The glob matched pathname with the given file type.
     """
 
@@ -127,7 +113,7 @@ def glob_scanners(pathnames, *, mode=1, recursive=False):
 
     Parameters
     ----------
-    pathnames : iterable of str or path-like
+    pathnames : iterable of str, bytes or path-like
         A list of pathnames with glob patterns.
     mode : int, default=1
         The mode of glob. If ``0``, disable glob pathname pattern; if ``1``,
@@ -138,7 +124,7 @@ def glob_scanners(pathnames, *, mode=1, recursive=False):
 
     Yields
     ------
-    matched_pathname : str
+    matched_pathname : str or bytes
         The glob matched pathname.
     """
 
@@ -152,21 +138,21 @@ def glob_filters(pathnames, *, mode=1, type="a", recursive=False):
 
     Parameters
     ----------
-    pathnames : iterable of str or path-like
+    pathnames : iterable of str, bytes or path-like
         A list of pathnames with glob patterns.
     mode : int, default=1
         The mode of glob. If ``0``, disable glob pathname pattern; if ``1``,
         resolve ``*`` and ``?``; if ``2``, resolve ``*``, ``?`` and ``[]``.
     type : str, default='a'
         The type of file. If ``a``, include all types; if ``d``, include
-        directories; if ``f``, include files; if ``l``, includes symbolic links.
+        directories; if ``f``, include files.
     recursive : bool, default=False
         If ``True``, the pattern ``**`` will match any files and zero or more
         directories, subdirectories and symbolic links to directories.
 
     Yields
     ------
-    matched_pathname : str
+    matched_pathname : str or bytes
         The glob matched pathname with the given file type.
     """
 
